%global debug_package %{nil}

Name:           xcaddy
Version:        0.4.2
Release:        1%{?dist}
Summary:        Build Caddy with plugins
License:        Apache-2.0
URL:            https://github.com/caddyserver/xcaddy

# Since we are not using a traditional source tarball, we need to explicitly
# pull in the license file.
Source80:       https://raw.githubusercontent.com/caddyserver/xcaddy/v%{version}/README.md
Source90:       https://raw.githubusercontent.com/caddyserver/xcaddy/v%{version}/LICENSE

# BuildRequires:  golang >= 1.22
BuildRequires:  git-core
BuildRequires:  systemd-rpm-macros


%description
This command line tool and associated Go package makes it easy to make custom builds of the Caddy Web Server.


%prep
%setup -q -c -T
# Copy main.go and LICENSE into the build directory.
cp %{S:80} %{S:90} .


%build
# https://pagure.io/go-rpm-macros/c/1cc7f5d9026175bb6cb1b8c889355d0c4fc0e40a
%undefine _auto_set_build_flags

# Fedora diverges from upstream Go by disabling the proxy server.  Some of
# Caddy's dependencies reference commits that are no longer upstream, but are
# cached in the proxy.  As long as we are downloading dependencies during the
# build, reset the behavior to prefer the proxy.  This also avoid having a
# build requirement on bzr.
# https://fedoraproject.org/wiki/Changes/golang1.13#Detailed_Description
export GOPROXY='https://proxy.golang.org,direct'

# As of 2023-08-03, golang 1.21 in Fedora Rawhide requires this environment
# variable to be set for the build to work correctly.
# https://github.com/golang/go/issues/60145#issuecomment-1547921152
export GOSUMDB='sum.golang.org'
export BUILDTAGS='%{!?suse_version:rpm_crashtraceback }nobadger'
export LDFLAGS='-s -w -buildid='
go mod init xcaddy
cat > main.go <<EOF
package main

import (
    xcaddycmd "github.com/caddyserver/xcaddy/cmd"
)

func main() {
    xcaddycmd.Main()
}
EOF
echo "require github.com/caddyserver/xcaddy v%{version}" >> go.mod
go mod tidy
env CGO_ENABLED=0 go build \
    -buildmode pie \
    -compiler gc \
    -tags="${BUILDTAGS}" \
    -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \n')%{?__global_ldflags: -extldflags '%__global_ldflags'}" \
    -a -v -x

%install
# command
install -D -p -m 0755 xcaddy %{buildroot}%{_bindir}/xcaddy

%files
%doc README.md
%license LICENSE
%{_bindir}/xcaddy
